Can

Struct Can 

pub struct Can { /* private fields */ }
implementation of CoE (Canopen Over Ethercat)

It works exactly as in a Can bus, except each of its frame is encapsulated in an ethercat mailbox frame, and PDOs access is therefore not realtime. For realtime PDOs exchange, they must be mapped to the logical memory using a SM (Sync Manager) channel.

Canopen protocol exposes 2 data structures:

  • a dictionnary of simple values or single level structures, for non-realtime access

    these are named SDO (Service Data Object). See crate::sdo for more details

  • several buffers gathering dictionnary objects for realtime access

    these are named PDO (Process Data Object)

The following shows how the mapping of SDOs to PDOs is done, how it extends to logical memory in the case of CoE, and how the master interacts with each memory area.

CoE mapping

This scheme comes in addition to the slave memory areas described in crate::rawmaster::RawMaster, for slaves supporting CoE.

A Can instance is generally obtained from Slave::coe

Implementations

Source

impl Can

pub fn new(mailbox: Arc<Mutex<Mailbox>>) -> Can

pub async fn sdo_read<T: PduData>( &mut self, sdo: &Sdo<T>, priority: u2, ) -> EthercatResult<T, CanError>

read an SDO, any size

pub async fn sdo_read_slice<'b>( &mut self, sdo: &Sdo, priority: u2, data: &'b mut [u8], ) -> EthercatResult<&'b mut [u8], CanError>

pub async fn sdo_write<T: PduData>( &mut self, sdo: &Sdo<T>, priority: u2, data: T, ) -> EthercatResult<(), CanError>

write an SDO, any size

pub async fn sdo_write_slice( &mut self, sdo: &Sdo, priority: u2, data: &[u8], ) -> EthercatResult<(), CanError>

pub fn pdo_read()

pub fn pdo_write()

pub fn info_dictionnary()

pub fn info_sdo()

pub fn info_subitem()