pub struct DistributedClock { /* private fields */ }Expand description
implementation of the Distributed Clock (DC) at the master level.
The time offsets and delays measured by this clock synchronization mode are shows in the following chronogram for one packet sending.
Implementations
Sourceimpl DistributedClock
impl DistributedClock
Sourcepub async fn new(
master: Arc<RawMaster>,
delays_samples: Option<usize>,
offsets_samples: Option<usize>,
) -> EthercatResult<Self>
pub async fn new( master: Arc<RawMaster>, delays_samples: Option<usize>, offsets_samples: Option<usize>, ) -> EthercatResult<Self>
initialize the distributed clock on the ethercat segment
Since the slaves responsibilities in the distributed clock only depend from the topology of the network, this initializer will automatically detect the topology and act accordingly
parameters
delays_samples: number of clock sampling used in estimating the propagation delays between slaves (defaults to8)offsets_samples: number of clock sampling used in estimating the offsets between slaves clocks (defaults to15_000)
Sourcepub fn referent(&self) -> SlaveAddress
pub fn referent(&self) -> SlaveAddress
getters return the slave address of the slave used as reference clock. This slave is called referent, or reference slave.
Sourcepub fn epoch(&self) -> i128
pub fn epoch(&self) -> i128
offset between the ethercat system clock (arbitrarily zeroed) and unix epoch. In this implementation, the ethercat system clock zero is when this struct is initialized
Sourcepub fn offset(&self, slave: SlaveAddress) -> i128
pub fn offset(&self, slave: SlaveAddress) -> i128
time offset from given slave clock to the reference clock
Sourcepub fn delay(&self, slave: SlaveAddress) -> i128
pub fn delay(&self, slave: SlaveAddress) -> i128
return the transmission delay from the reference slave to the given slave
Sourcepub fn offset_master(&self) -> i128
pub fn offset_master(&self) -> i128
time offset from the reference clock to the master clock
Sourcepub fn delay_master(&self) -> i128
pub fn delay_master(&self) -> i128
return the transmission delay from the master to the reference slave
Sourcepub async fn sync(&self)
pub async fn sync(&self)
distributed clock synchronisation step. It must be called periodically to save the distributed clock from divergence
Sourcepub async fn sync_loop(&self, period: Duration)
pub async fn sync_loop(&self, period: Duration)
distributed clock synchronisation task. Using cycle time as execution period
Once the automatic control is start, time cannot period cannot be changed. Start cyclic time correction only with conitnuous drift flag set.
One task only should run this function at the same time. It will be calling Self::sync