pub struct SyncChannel {
pub direction: SyncDirection,
pub index: u16,
pub capacity: u8,
}Expand description
description of SDO configuring a SyncChannel
the SDO is assumed to follow the cia402 specifications for syncmanager SDOs (ETG.1000.6 table 77)
Fields
direction: SyncDirectionwhether this channel is to be read or written by the master, this might be set by the user if the slave supports it.
index: u16index of the SDO that configures the SyncChannel
capacity: u8max number of PDO that can be assigned to the SyncChannel
Implementations
Sourceimpl SyncChannel
impl SyncChannel
Sourcepub fn slot(&self, i: u8) -> Sdo<u16>
pub fn slot(&self, i: u8) -> Sdo<u16>
return a field pointing to the nth entry definition of the sync manager channel
Sourcepub const fn len(&self) -> Sdo<u8>
pub const fn len(&self) -> Sdo<u8>
return a field pointing to the number of items set in the sync manager channel
Sourcepub fn register(&self) -> Field<SyncManagerChannel>
pub fn register(&self) -> Field<SyncManagerChannel>
register matching this sync channel sdo
Sourcepub fn sync(&self) -> Synchronization
pub fn sync(&self) -> Synchronization
sdo setting up the task synchronization to the sync channel