pub struct SiiControl { /* private fields */ }Expand description
register controling the read/write operations to Slave Information Interface (SII)
ETG.1000.4 table 49
Implementations
Sourceimpl SiiControl
impl SiiControl
pub fn new( write_access: bool, eeprom_emulation: bool, read_size: SiiTransaction, address_unit: SiiUnit, read_operation: bool, write_operation: bool, reload_operation: bool, checksum_error: bool, device_info_error: bool, command_error: bool, write_error: bool, busy: bool, ) -> Self
Sourcepub fn write_access(&self) -> bool
pub fn write_access(&self) -> bool
true if SII is writable
Sourcepub fn set_write_access(&mut self, value: bool)
pub fn set_write_access(&mut self, value: bool)
true if SII is writable
Sourcepub fn eeprom_emulation(&self) -> bool
pub fn eeprom_emulation(&self) -> bool
- false: Normal operation (DL interfaces to SII)
- true: DL-user emulates SII
cannot be set by the master
Sourcepub fn set_eeprom_emulation(&mut self, value: bool)
pub fn set_eeprom_emulation(&mut self, value: bool)
- false: Normal operation (DL interfaces to SII)
- true: DL-user emulates SII
cannot be set by the master
Sourcepub fn read_size(&self) -> SiiTransaction
pub fn read_size(&self) -> SiiTransaction
number of bytes per read transaction, cannot be set by master
Sourcepub fn set_read_size(&mut self, value: SiiTransaction)
pub fn set_read_size(&mut self, value: SiiTransaction)
number of bytes per read transaction, cannot be set by master
Sourcepub fn address_unit(&self) -> SiiUnit
pub fn address_unit(&self) -> SiiUnit
unit of SII addresses, cannot be set by master
Sourcepub fn set_address_unit(&mut self, value: SiiUnit)
pub fn set_address_unit(&mut self, value: SiiUnit)
unit of SII addresses, cannot be set by master
Sourcepub fn read_operation(&self) -> bool
pub fn read_operation(&self) -> bool
read operation requested (parameter write) or read operation busy (parameter read) To start a new read operation there must be a positive edge on this parameter
This parameter will be written from the master to start the read operation of 32 bits/64 bits in the slave information interface. This parameter will be read from the master to check if the read operation is finished.
Sourcepub fn set_read_operation(&mut self, value: bool)
pub fn set_read_operation(&mut self, value: bool)
read operation requested (parameter write) or read operation busy (parameter read) To start a new read operation there must be a positive edge on this parameter
This parameter will be written from the master to start the read operation of 32 bits/64 bits in the slave information interface. This parameter will be read from the master to check if the read operation is finished.
Sourcepub fn write_operation(&self) -> bool
pub fn write_operation(&self) -> bool
write operation requested (parameter write) or write operation busy (parameter read) To start a new write operation there must be a positive edge on this parameter
This parameter will be written from the master to start the write operation of 16 bits in the slave information interface. This parameter will be read from the master to check if the write operation is finished. There is no consistence gu arantee for write operation. A break down during write can produce inconsistent values and should be avoided.
Sourcepub fn set_write_operation(&mut self, value: bool)
pub fn set_write_operation(&mut self, value: bool)
write operation requested (parameter write) or write operation busy (parameter read) To start a new write operation there must be a positive edge on this parameter
This parameter will be written from the master to start the write operation of 16 bits in the slave information interface. This parameter will be read from the master to check if the write operation is finished. There is no consistence gu arantee for write operation. A break down during write can produce inconsistent values and should be avoided.
Sourcepub fn reload_operation(&self) -> bool
pub fn reload_operation(&self) -> bool
reload operation requested (parameter write) or reload operation busy (parameter read) To start a new reload operation there must be a positive edge on this parameter
This parameter will be written from the master to start the reload operation of the first 128 bits in the slave information interface. This parameter will be read from the master to check if the reload operation is finished
Sourcepub fn set_reload_operation(&mut self, value: bool)
pub fn set_reload_operation(&mut self, value: bool)
reload operation requested (parameter write) or reload operation busy (parameter read) To start a new reload operation there must be a positive edge on this parameter
This parameter will be written from the master to start the reload operation of the first 128 bits in the slave information interface. This parameter will be read from the master to check if the reload operation is finished
Sourcepub fn checksum_error(&self) -> bool
pub fn checksum_error(&self) -> bool
checksum error while reading at startup
Sourcepub fn set_checksum_error(&mut self, value: bool)
pub fn set_checksum_error(&mut self, value: bool)
checksum error while reading at startup
Sourcepub fn device_info_error(&self) -> bool
pub fn device_info_error(&self) -> bool
error on reading Device Information
Sourcepub fn set_device_info_error(&mut self, value: bool)
pub fn set_device_info_error(&mut self, value: bool)
error on reading Device Information
Sourcepub fn command_error(&self) -> bool
pub fn command_error(&self) -> bool
error on last SII request
writable only in SII emulation mode
Sourcepub fn set_command_error(&mut self, value: bool)
pub fn set_command_error(&mut self, value: bool)
error on last SII request
writable only in SII emulation mode
Sourcepub fn write_error(&self) -> bool
pub fn write_error(&self) -> bool
error on last write operation
Sourcepub fn set_write_error(&mut self, value: bool)
pub fn set_write_error(&mut self, value: bool)
error on last write operation